package org.osconsulting.jerr;

import java.util.List;

import org.osconsulting.l10n.msgstore.ConfigurationManager;
import org.osconsulting.l10n.msgstore.MessageStore;
/**
 * JErr custom implementation of the JErrorCategory. This class defines
 * the error codes used in JErr itself. Yes we are using our own framework
 * for error handling. 
 * 
 * The ErrorCode.code must correspond to an entry in the appropriate message store.
 * 
 * @author kstam
 *
 */
public class JErrCategory extends JErrCategoryBase
{
    private static final long serialVersionUID = 1L;
    private static List<MessageStore> _messageStores = ConfigurationManager.getInstance().getMessageStores(JErrCategory.class);
    
    
    /** undefined error (user passed in null value). */
    public static final JErrCode UE001_UNSPECIFIED_ERROR        = new JErrCode("UE001", _messageStores);
    
    /** fatal error in the JErr framework itself. */
    public static final JErrCode JE001_JERR_UNABLE_TO_RESPOND    = new JErrCode("JE001", _messageStores);
    /** error code for error codes which cannot be found the message store */
    public static final JErrCode JE002_JERROR_CODE_UNDEFINED     = new JErrCode("JE002", _messageStores);
    /** JErr category not found, or undefined in the jerr-config.xml */
    public static final JErrCode JE003_JERROR_CATEGORY_UNDEFINED = new JErrCode("JE003", _messageStores);
    /** JErr configfile not found, jerr-config.xml */
    public static final JErrCode JE004_JERROR_CONFIG_NOT_FOUND   = new JErrCode("JE004", _messageStores);
    /** JErr invalid messageQuery */
    public static final JErrCode JE005_INVALID_MESSAGEQRY        = new JErrCode("JE005", _messageStores);
    /** JErr bad database connection parameters / connection problem */
    public static final JErrCode JE006_DB_CONNECTION_ERROR       = new JErrCode("JE006", _messageStores);
    /** JErr invalid database driver */
    public static final JErrCode JE007_INVALID_JDBC_DRIVER       = new JErrCode("JE007", _messageStores);
    /** JErr invalid message store */
    public static final JErrCode JE008_INVALID_MESSAGE_STORE     = new JErrCode("JE008", _messageStores);
    /** JErr invalid JNDI reference */
    public static final JErrCode JE009_INVALID_JNDI_REF		     = new JErrCode("JE009", _messageStores);
}
