package org.osconsulting.jerr;

import java.io.Serializable;
import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * JErrorCategory is the base class of all JErrorCategories. The user must extend this
 * class and list all ErrorCodes for this new category. See JErrErrorCategory for an example
 * implementation.
 * 
 * @author kstam
 * Copyright 2006 osConsulting.org Kurt Stam and Shahar Bar
 *
 */
public abstract class JErrCategoryBase implements Serializable
{
    private Log log = LogFactory.getLog(this.getClass());
    private static final long serialVersionUID = 1L;
    private List<JErrCode> errorCodes = new ArrayList<JErrCode>();
    /**
     * Returns a list of <code>JErrorCode</code>s of all errorCode defined in
     * the current JErrorCategory.
     * @return - List of all <code>JErrorCode</code>s defined in this category.
     * @throws IllegalAccessException if an JErrorCode field is inaccessable
     */
    public List<JErrCode> getErrorCodeList() throws IllegalAccessException{
        log.info("Getting all errorCodes defined in class: " + this.getClass());
        Field[] fields = getClass().getFields();
        for (int i=0; i<fields.length; i++) {
            Field field = fields[i];
            if (field.getType().equals(JErrCode.class)) {
                JErrCode errorCode = (JErrCode) field.get(field);
                if (log.isDebugEnabled()) {
                    log.debug("Adding JErrorCode: " + errorCode.getKey() + " to the list.");
                }
                errorCodes.add(errorCode);
            }
        }
        return errorCodes;
    }

    
}
