package org.osconsulting.l10n;

import java.io.Serializable;
import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.osconsulting.l10n.msgstore.MessageStore;

/**
 * L10nBaseCategory is the base class of all L10nCategories. The user must extend this
 * class and list all string keys for this new category. See L10nCategory for an example
 * implementation.
 * 
 * @author kstam
 * Copyright 2006 osConsulting.org Kurt Stam and Shahar Bar
 *
 */
public abstract class MessageCategoryBase implements Serializable
{
    private Log log = LogFactory.getLog(this.getClass());
    private static final long serialVersionUID = 1L;
    private static List<MessageStore> _messageStores = new ArrayList<MessageStore>();
 
    /**
     * Returns a list of keys of all errorCode defined in
     * the current JErrorCategory.
     * @return - List of all keys defined in this category.
     * @throws IllegalAccessException if a key is inaccessable
     */
    public List<LocalizedMessage> getLocalizedMessageList() throws IllegalAccessException{
        log.info("Getting all keys defined in class: " + this.getClass());
        List<LocalizedMessage> compileTimeKeys = new ArrayList<LocalizedMessage>();
        Field[] fields = getClass().getFields();
        for (int i=0; i<fields.length; i++) {
            Field field = fields[i];
            if (field.getType().equals(LocalizedMessage.class)) {
                LocalizedMessage localizedMessage = (LocalizedMessage) field.get(field);
                if (log.isDebugEnabled()) {
                    log.debug("Adding localizedMessage: " + localizedMessage.getKey() + " to the list.");
                }
                compileTimeKeys.add(localizedMessage);
            }
        }
        return compileTimeKeys;
    }
    
    public List<MessageStore> getMessageStores(Class messageCategory)
    {
        //TODO handle a flag here to re-read the configuration
        if (_messageStores==null)
        {
            //TODO _
        }
        return _messageStores;
    }

    
}
